Package: RITAN
Type: Package
Title: Rapid Integration of Term Annotation and Network resources
Version: 1.34.0
Authors@R: c(person("Michael", "Zimmermann", role = c("aut", "cre"),
                    email = "mtzimmermann@mcw.edu"))
Description: Tools for comprehensive gene set enrichment and extraction of
    multi-resource high confidence subnetworks. RITAN facilitates bioinformatic
    tasks for enabling network biology research.
LazyData: TRUE
Depends: R (>= 4.0),
Imports: graphics, methods, stats, utils, grid, gridExtra, reshape2,
        gplots, ggplot2, plotrix, RColorBrewer, STRINGdb, MCL,
        dynamicTreeCut, gsubfn, hash, png, sqldf, igraph, BgeeDB,
        knitr, RITANdata, GenomicFeatures, ensembldb, AnnotationFilter,
        EnsDb.Hsapiens.v86
VignetteBuilder: knitr
Collate: 'lib_enrichment.R' 'lib_network.R'
        'interconnectivity_functions.R'
RoxygenNote: 7.3.2
Suggests: rmarkdown, BgeeDB
License: file LICENSE
biocViews: QualityControl, Network, NetworkEnrichment,
        NetworkInference, GeneSetEnrichment, FunctionalGenomics,
        GraphAndNetwork
NeedsCompilation: no
git_url: https://git.bioconductor.org/packages/RITAN
git_branch: RELEASE_3_22
git_last_commit: 0863028
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
Packaged: 2025-10-30 06:06:20 UTC; biocbuild
Author: Michael Zimmermann [aut, cre]
Maintainer: Michael Zimmermann <mtzimmermann@mcw.edu>
