# Generated by roxygen2: do not edit by hand

S3method(plot,term_enrichment)
S3method(plot,term_enrichment_by_subset)
S3method(summary,term_enrichment)
S3method(summary,term_enrichment_by_subset)
export(as.graph)
export(check_any_net_input)
export(check_net_input)
export(enrichment_symbols)
export(geneset_overlap)
export(icon_test)
export(load_geneset_symbols)
export(network_overlap)
export(readGMT)
export(readSIF)
export(resource_reduce)
export(show_active_genesets_hist)
export(term_enrichment)
export(term_enrichment_by_subset)
export(writeGMT)
export(write_simple_table)
import(AnnotationFilter)
import(EnsDb.Hsapiens.v86)
import(GenomicFeatures)
import(MCL)
import(RColorBrewer)
import(RITANdata)
import(STRINGdb)
import(dynamicTreeCut)
import(ensembldb)
import(ggplot2)
import(gplots)
import(graphics)
import(grid)
import(gridExtra)
import(gsubfn)
import(igraph)
import(plotrix, except=c('plotCI'))
import(png)
import(reshape2)
import(sqldf)
import(stats, except=c('decompose','lowess','spectrum'))
import(utils)
importFrom(methods,is)
